# SEC01-BP05: Reduce security management scope

## Description

Giảm scope cần manage (use managed services).

## Implementation Guidance

- Managed services over self-managed
- Serverless where possible
- Shared responsibility model understanding
- Outsource non-core security
- Focus on application security

## Risk Level

Medium - Large scope increases attack surface.
